<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished">Conflit d&apos;adresses IP</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Mode avion</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Interrompre la communication sans-fil</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>L&apos;activation du mode avion désactive le réseau sans fil, le point d&apos;accès personnel et le Bluetooth.</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy d&apos;application</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configurer le serveur proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP invalide</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port invalide</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Facultatif</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Cochez &quot;Utiliser un proxy&quot; dans le menu contextuel de l&apos;application dans le lanceur après la configuration.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Configurer une connexion réseau à accès commuté</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Ajouter une connexion PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Êtes-vous sûr de vouloir supprimer cette configuration ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Détails du réseau</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Afficher toutes les configurations réseau</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Les détails ont été copiés.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Sélectionner tout</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Détection du réseau</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personnel</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personnel</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Non lié</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Point d&apos;accès personnel</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Partager le réseau</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Mon point d&apos;accès</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Modifier mon point d&apos;accès</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nom (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Paramètres partagés</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Périphérique de partage de point d&apos;accès</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Si vous souhaitez utiliser le point d&apos;accès personnel, désactivez d&apos;abord le mode Avion, puis activez la carte réseau sans fil.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Si vous souhaitez utiliser le point d&apos;accès personnel, désactivez d&apos;abord le &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Mode avion&lt;/a&gt;, puis activez la carte réseau sans fil.</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Êtes-vous sûr de vouloir supprimer cette configuration ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy système</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configurer le serveur proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuration</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorer les configurations de proxy pour les hôtes et domaines ci-dessus</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Connecter, ajouter, importer</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Ajouter un VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importer un VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Erreur d&apos;importation</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Erreur de fichier</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>Type de VPN</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Êtes-vous sûr de vouloir supprimer cette configuration ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>connecter, modifier les paramètres réseau</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Branchez le câble réseau en premier.</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Ajouter une connexion réseau</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Connecter, modifier les paramètres réseau</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Autres réseaux</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Désactivez d&apos;abord le mode Avion si vous souhaitez vous connecter à un réseau sans fil.</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Désactivez d&apos;abord le &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Mode avion&lt;/a&gt; si vous souhaitez vous connecter à un réseau sans fil.</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Désactivez d&apos;abord le point d&apos;accès si vous souhaitez vous connecter à un réseau sans fil.</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Désactivez le point d&apos;accès&lt;/a&gt; si vous souhaitez vous connecter à un réseau sans fil.</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation type="unfinished">Mes réseaux</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP invalide</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Non lié</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WIFI</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresse MAC du périphérique</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adresse MAC clonée</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personnaliser la MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nom (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Connexion automatique</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Applicable uniquement aux ressources correspondantes</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP invalide</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passerelle</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Masque de réseau invalide</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adresse IP en double</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Applicable uniquement aux ressources correspondantes</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP invalide</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passerelle</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Masque de réseau invalide</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adresse IP en double</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utiliser MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128 bits</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE étatique</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuser l&apos;authentification EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuser l&apos;authentification PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuser l&apos;authentification CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pas de compression des données BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Pas de compression de données Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Pas de compression d&apos;en-tête TCP</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envoyer des paquets d&apos;écho PPP</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS en tunnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protégé</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personnel</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Entreprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personnel</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Authentification EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Options du mot de passe</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Enregistrer le mot de passe pour cet utilisateur</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Enregistrer le mot de passe pour tous les utilisateurs</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Toujours demander</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clé</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Mot de passe privé</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clé partagée</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Système ouvert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clé privée</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Identifiant anonyme</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisionnement</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonyme</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Authentifié</translation>
    </message>
    <message>
        <source>Both</source>
        <translation> Les deux</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>fichier PAC</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Autorité de certification</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certification utilisateur</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Version PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Authenticité interne</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passerelle</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Autorité de certification</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Autoriser le cheval de Troie Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Type d&apos;authentification</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clé privée</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Carte à puce</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clé pré-partagée</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certification utilisateur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Utiliser FSID comme phrase secrète principale</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificats (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificats avec mot de passe (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Clé statique</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Options du mot de passe</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sauvegardé</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requis</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Mot de passe privé</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personnaliser la clé de direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Clé de direction</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP distante</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP locale</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domaine NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Demander une adresse IP interne</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Appliquer l&apos;encapsulation UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Utiliser la compression IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activer les propositions de chiffrement personnalisées</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nom du groupe</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Mot de passe du groupe</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Utiliser l&apos;authentification hybride</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Fichier CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utiliser MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tous disponibles (par défaut)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 bits (moins sécurisé)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 bits (plus sécurisé)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE étatique</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuser l&apos;authentification EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuser l&apos;authentification PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuser l&apos;authentification CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pas de compression des données BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Pas de compression de données Deflate</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Pas de compression d&apos;en-tête TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Pas de compression du champ de protocole</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Pas de compression d&apos;adresse/contrôle</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envoyer des paquets d&apos;écho PPP</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activer IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Identifiant du groupe</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algorithmes de phase 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algorithmes de phase 2</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN avancé</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personnaliser le port de passerelle</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port de passerelle</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personnaliser l&apos;intervalle de renégociation</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalle de renégociation</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Utiliser la compression de données LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Utiliser une connexion TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Utiliser un périphérique TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personnaliser le tunnel MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personnaliser la taille des fragments UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Taille des fragments UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restriction du tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Randomiser les hôtes distants</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domaine</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendeur</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (par défaut)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Chiffrement</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sécurisé (par défaut)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Faible</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mode de traversée NAT</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T lorsque disponible (par défaut)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Toujours</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Groupe IKE DH</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Groupe DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Groupe DH 2 (par défaut)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Groupe DH 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Confidentialité persistante</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Serveur (par défaut)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Groupe DH 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Désactiver la détection des pairs inactifs</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>Sécurité VPN</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Chiffrer</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Authentification HMAC</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP du serveur</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Réessayer indéfiniment en cas d&apos;échec</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Authentification VPN TLS</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Correspondance des sujets</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Type de certificat distant</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serveur</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Fichier clé</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Facultatif</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>L&apos;authentification est requise.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requis</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Désactivez d&apos;abord le &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Mode avion&lt;/a&gt; si vous souhaitez vous connecter à un réseau sans fil.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflit d&apos;adresses IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Connexion filaire %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Connexion PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Connexion à &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; connecté</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; déconnecté</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Impossible de se connecter à &quot;%1&quot;, veuillez vérifier votre routeur ou votre câble réseau.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Impossible de se connecter à &quot;%1&quot;, veuillez vous rapprocher du routeur sans fil.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Échec de la connexion, impossible de se connecter à &quot;%1&quot;, mot de passe incorrect.</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Un mot de passe est nécessaire pour se connecter à &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Le réseau WIFI 802.11 &quot;%1&quot; est introuvable.</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Pour vous connecter à &quot;%1&quot;, veuillez configurer vos informations d&apos;authentification après vous être connecté.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy système</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>La configuration VPN n&apos;est pas connectée ou n&apos;a pas pu se connecter. Veuillez vous &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;rendre au centre de contrôle&lt;/a&gt; pour vérification.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Se connecter à un réseau masqué</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Mes réseaux</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Autres réseaux</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
